# Copyrights 2001-2014 by [Mark Overmeer].
#  For other contributors see ChangeLog.
# See the manual pages for details on the licensing terms.
# Pod stripped from pm file by OODoc 2.01.

package MailBox::Test::53threads::Definition;
use vars '$VERSION';
$VERSION = '2.115';


sub name     {"Mail::Box::Threads; message threads"}
sub critical {0}
sub skip     { undef }

1;
